import processing.video.*;
import FaceDetect.*;
import megamu.shapetween.*;

FaceDetect fd;
Capture cam;

int MAX = 10;

int[] x = new int[MAX];
int[] y = new int[MAX];
int[] r = new int[MAX];
int[][] faces = new int[MAX][3];

float faceX = 0.0;
float faceY = 0.0;
float faceRadius = 0.0;

final int WIDTH = 1024;
final int HEIGHT = 600;

VideoPlayer videoPlayer;

final int TILES_COUNT = 3;
Tile[] tiles = new Tile[TILES_COUNT];

PImage topBar;

private float dx;
private float dy;
private int lastFaceX;
private int lastFaceY;
private int lastFaceRadius;

PImage launcher;
boolean isLauncherVisible = false;
Tween launcherAni;
boolean DEBUG_MODE = false;

void setup(){
  frameRate(30);
  size(WIDTH,HEIGHT,P2D);
  cam = new Capture(this, 320, 240);
  fd = new FaceDetect(this);
  fd.start("haarcascade_frontalface_alt.xml", width,height,30);
  
  videoPlayer = new VideoPlayer(cam, this);
  
  topBar = loadImage("top-bar.png");
  
  tiles[0] = new Tile(loadImage("dictionary.png"), 70, 30, 5);
  tiles[1] = new Tile(loadImage("calculator.png"), 700, 30, 15);
  tiles[2] = new Tile(loadImage("mines.png"), 750, 400, 10);
  
  launcher = loadImage("launcher.png");
  launcherAni = new Tween(this, 0.5, Tween.SECONDS);
  launcherAni.reverse();
  launcherAni.start();
  launcherAni.pause();
  
  
  println("POSITION: " + launcherAni.position());
  
  
}

void movieEvent(Movie myMovie) {
  myMovie.read();
}

void draw(){
  background(0);
  
  for(int i=0; i<TILES_COUNT; i++){
    tiles[i].draw(g);
  }
  
  videoPlayer.draw(g);
  
  image(launcher, - launcher.width * launcherAni.position(), 0 );
  image(topBar,0,0);
  
  boolean detected = false;
  
  if (cam.available()) {
    cam.read();

    faces = fd.face(cam);
    int count = faces.length;
    //    println(count);
    if (count>0) {
      lastFaceX = faces[0][0];
      lastFaceY = faces[0][1];
      lastFaceRadius = faces[0][2];
      updateFace(lastFaceX, lastFaceY, lastFaceRadius);
      
      detected = true;
    }
  }
  if(!inited || !DEBUG_MODE)
    return;
  // draw ellipse
  noFill();
  if(detected){
    stroke(255);
  }else{
    stroke(255,0,0);
    updateFace(lastFaceX, lastFaceY, lastFaceRadius);
  }
  float d = faceRadius * 2.0f;
  ellipse(faceX,faceY,d,d);
}

float speed = 0.5f;
boolean inited = false;

void updateFace(int x, int y, int radius)
{
  if(!inited){
    faceX = x * 1.0f;
    faceY = y * 1.0f;
    faceRadius = radius * 1.0f;
    inited = true;
    return;
  }
  
  faceX += ((x * 1.0f) - faceX) * speed;
  faceY += ((y * 1.0f) - faceY) * speed;
  faceRadius += ((radius * 1.0f) - faceRadius) * speed;
  
  dx = faceX - (WIDTH * .5f);
  dy = faceY - (HEIGHT * .5f);
  if(dx < -50 && !isLauncherVisible && !videoPlayer.isFullscreen){
    //println("SHOW DX: " + dx);
    showLauncher();
  }else if(dx >= -50 && isLauncherVisible){
    //println("HIDE DX: " + dx);
    hideLauncher();
  }
  if(faceRadius < 100 && !videoPlayer.isFullscreen){
    videoPlayer.doFullscreen();
    if(isLauncherVisible)
      hideLauncher();
  }else if(faceRadius >= 100 && videoPlayer.isFullscreen){
    videoPlayer.undoFullscreen();
  }
  //println("radius: " + faceRadius);
  for(int i=0; i<TILES_COUNT; i++){
    tiles[i].updateOffset(-dx, -dy);
  }
}

void showLauncher(){
  moveLauncher(true);
}

void hideLauncher(){
  moveLauncher(false);
}

void moveLauncher(boolean visible){
  launcherAni.pause();
  launcherAni = new Tween(this, 0.3, Tween.SECONDS);
  if(visible)
    launcherAni.reverse();
  launcherAni.start();
  isLauncherVisible = visible;
}

void keyPressed ()
{
  if (key == 'd' || key == 'D') {
    DEBUG_MODE = !DEBUG_MODE;
  }
}
