class VideoPlayer
{
  final private int WIDTH = 418;
  final private int HEIGHT = 396;
  final private int DISPLAY_X = 2;
  final private int DISPLAY_Y = 55;
  
  final private int X = 100;
  final private int Y = 40;
  
  private PImage bgImage;
  private Capture movie;
  
  private float movieScale;
  private float movieX;
  private float movieY;
  
  private PApplet applet;
  public boolean isFullscreen = false;
  Tween fullscreenAni;
  
  private float movieW;
  private float movieH;
  private float movieFullscreenW;
  private float movieFullscreenH;
  
  public VideoPlayer(Capture movie, PApplet applet){
    println("WIDTH: " + applet.width + " h:" + applet.height);
    this.bgImage = loadImage("media-player.png");
    this.movie = movie;
    this.applet = applet;
    
    float scaleX = (WIDTH * 1.0f) / movie.width;
    float scaleY = (HEIGHT * 1.0f) / movie.height;
    
    movieScale = min(scaleX, scaleY);
    movieW = movie.width * movieScale;
    movieH = movie.height * movieScale;
    movieX = (WIDTH - movieW) * .5;
    movieY = (HEIGHT - movieH) * .5;
    
    scaleX = (applet.width * 1.0f) / movie.width;
    scaleY = (applet.height * 1.0f) / movie.height;
    float movieFullscreenScale = min(scaleX, scaleY);
    movieFullscreenW = movie.width * movieFullscreenScale;
    movieFullscreenH = movie.height * movieFullscreenScale;
    
    fullscreenAni = new Tween(applet, 0.5, Tween.SECONDS);
    fullscreenAni.pause();
    
    //print("x:" + scaleX + " y:" + scaleY);
  }
  
  public void draw(PGraphics g){
    g.image(bgImage, X, Y);
    g.fill(0, 255 *fullscreenAni.position());
    g.noStroke();
    g.rect(0,0,applet.width, applet.height);
    g.image(movie, getVideoX(), getVideoY(), getVideoW(), getVideoH());
  }
  
  private float getVideoX () {
    float x = X + DISPLAY_X + movieX;
    float xf = (applet.width - movieFullscreenW) * .5f;
    return x + (xf-x) * fullscreenAni.position();
  }
  
  private float getVideoY () {
    return (Y + DISPLAY_Y + movieY) * (1.0f - fullscreenAni.position());
  }
  
  private float getVideoW () {
    return movieW + (movieFullscreenW - movieW) * fullscreenAni.position();
  }
  
  private float getVideoH () {
    return movieH + (movieFullscreenH - movieH) * fullscreenAni.position();
  }
  
  public void doFullscreen (){
    fullscreenAni.pause();
    fullscreenAni = new Tween(applet, 0.5, Tween.SECONDS);
    fullscreenAni.start();
    isFullscreen = true;
  }
  
  public void undoFullscreen(){
    fullscreenAni = new Tween(applet, 0.5, Tween.SECONDS);
    fullscreenAni.reverse();
    fullscreenAni.start();
    isFullscreen = false;
  }
}
